@@ -17,7 +17,7 @@ using namespace apolloron;
 
 const char *INKF_PROGNAME = "inkf";
 const char *INKF_BRIEF    = "Yet Another Network Kanji Filter";
-const char *INKF_VERSION  = "1.1.5";
+const char *INKF_VERSION  = "1.1.6";
 const char *INKF_COPY     = "Copyright (C) 2002-2018 Masashi Astro Tachibana";
 const char *INKF_DEF_OUT  = "inkf.out";
 
@@ -163,7 +163,7 @@ int main(int argc, char *argv[]) {
         }
 
         // read from file(s) or specified URL
-        for (i = 0; option.input_filenames[i] != '\0'; i++) {
+        for (i = 0; option.input_filenames[i] != NULL; i++) {
             if (charset_autodetect_pre) {
                 strcpy(option.input_charset, "AUTODETECT");
             }
