@@ -757,16 +757,23 @@ std::string JSONReader::getLocationLineAndColumn(Location location) const {
 }
 
 
-std::string JSONReader::getFormatedErrorMessages() const {
-    std::string formattedMessage;
+String JSONReader::getFormatedErrorMessages() const {
+    String formattedMessage;
     for(Errors::const_iterator itError = errors_.begin();
             itError != errors_.end();
             ++itError) {
         const ErrorInfo &error = *itError;
-        formattedMessage += "* " + getLocationLineAndColumn(error.token_.start_) + "\n";
-        formattedMessage += "  " + error.message_ + "\n";
-        if(error.extra_)
-            formattedMessage += "See " + getLocationLineAndColumn(error.extra_) + " for detail.\n";
+        formattedMessage += "* ";
+        formattedMessage += getLocationLineAndColumn(error.token_.start_).c_str();
+        formattedMessage += "\n";
+        formattedMessage += "  ";
+        formattedMessage += error.message_.c_str();
+        formattedMessage += "\n";
+        if (error.extra_) {
+            formattedMessage += "See ";
+            formattedMessage += getLocationLineAndColumn(error.extra_).c_str();
+            formattedMessage += " for detail.\n";
+        }
     }
     return formattedMessage;
 }
@@ -776,7 +783,7 @@ std::istream& operator>>(std::istream &sin, JSONValue &root) {
     apolloron::JSONReader reader;
     bool ok = reader.parse(sin, root, true);
     //JSON_ASSERT( ok );
-    if(!ok) throw std::runtime_error(reader.getFormatedErrorMessages());
+    if(!ok) throw std::runtime_error(reader.getFormatedErrorMessages().c_str());
     return sin;
 }
 
