@@ -33,7 +33,7 @@ static void uintToString(unsigned int value,
     } while(value != 0);
 }
 
-std::string valueToString(Int value) {
+String valueToString(Int value) {
     char buffer[32];
     char *current = buffer + sizeof(buffer);
     bool isNegative = value < 0;
@@ -47,7 +47,7 @@ std::string valueToString(Int value) {
 }
 
 
-std::string valueToString(UInt value) {
+String valueToString(UInt value) {
     char buffer[32];
     char *current = buffer + sizeof(buffer);
     uintToString(value, current);
@@ -55,7 +55,7 @@ std::string valueToString(UInt value) {
     return current;
 }
 
-std::string valueToString(double value) {
+String valueToString(double value) {
     char buffer[32];
 #if defined(_MSC_VER) && defined(__STDC_SECURE_LIB__) // Use secure version with visual studio 2005 to avoid warning. 
     sprintf_s(buffer, sizeof(buffer), "%#.16g", value);
@@ -94,20 +94,20 @@ std::string valueToString(double value) {
 }
 
 
-std::string valueToString(bool value) {
+String valueToString(bool value) {
     return value ? "true" : "false";
 }
 
-std::string valueToQuotedString(const char *value) {
+String valueToQuotedString(const char *value) {
     // Not sure how to handle unicode...
     if(strpbrk(value, "\"\\\b\f\n\r\t") == NULL && !containsControlCharacter(value))
-        return std::string("\"") + value + "\"";
+        return String("\"") + value + "\"";
     // We have to walk value and escape any special characters.
     // Appending to std::string is not efficient, but this should be rare.
     // (Note: forward slashes are *not* rare, but I am not escaping them.)
     unsigned maxsize = strlen(value) * 2 + 3; // allescaped+quotes+NULL
-    std::string result;
-    result.reserve(maxsize); // to avoid lots of mallocs
+    String result;
+    result.setFixedLength(maxsize); // to avoid lots of mallocs
     result += "\"";
     for(const char* c = value; *c != 0; ++c) {
         switch(*c) {
@@ -188,19 +188,19 @@ void JSONFastWriter::writeValue(const JSONValue &value) {
             document_ += "null";
             break;
         case intValue:
-            document_ += valueToString(value.asInt());
+            document_ += valueToString(value.asInt()).c_str();
             break;
         case uintValue:
-            document_ += valueToString(value.asUInt());
+            document_ += valueToString(value.asUInt()).c_str();
             break;
         case realValue:
-            document_ += valueToString(value.asDouble());
+            document_ += valueToString(value.asDouble()).c_str();
             break;
         case stringValue:
-            document_ += valueToQuotedString(value.asCString());
+            document_ += valueToQuotedString(value.c_str()).c_str();
             break;
         case booleanValue:
-            document_ += valueToString(value.asBool());
+            document_ += valueToString(value.asBool()).c_str();
             break;
         case arrayValue: {
             document_ += "[";
@@ -222,7 +222,7 @@ void JSONFastWriter::writeValue(const JSONValue &value) {
                 const std::string &name = *it;
                 if(it != members.begin())
                     document_ += ",";
-                document_ += valueToQuotedString(name.c_str());
+                document_ += valueToQuotedString(name.c_str()).c_str();
                 document_ += yamlCompatiblityEnabled_ ? ": "
                              : ":";
                 writeValue(value[name]);
@@ -270,7 +270,7 @@ void JSONStyledWriter::writeValue(const JSONValue &value) {
             pushValue(valueToString(value.asDouble()));
             break;
         case stringValue:
-            pushValue(valueToQuotedString(value.asCString()));
+            pushValue(valueToQuotedString(value.c_str()));
             break;
         case booleanValue:
             pushValue(valueToString(value.asBool()));
@@ -324,7 +324,7 @@ void JSONStyledWriter::writeArrayValue(const JSONValue &value) {
                 const JSONValue &childValue = value[index];
                 writeCommentBeforeValue(childValue);
                 if(hasChildValue)
-                    writeWithIndent(childValues_[index]);
+                    writeWithIndent(childValues_[index].c_str());
                 else {
                     writeIndent();
                     writeValue(childValue);
@@ -378,11 +378,11 @@ bool JSONStyledWriter::isMultineArray(const JSONValue &value) {
 }
 
 
-void JSONStyledWriter::pushValue(const std::string &value) {
+void JSONStyledWriter::pushValue(const String &value) {
     if(addChildValues_)
-        childValues_.push_back(value);
+        childValues_.push_back(value.c_str());
     else
-        document_ += value;
+        document_ += value.c_str();
 }
 
 
@@ -398,9 +398,9 @@ void JSONStyledWriter::writeIndent() {
 }
 
 
-void JSONStyledWriter::writeWithIndent(const std::string &value) {
+void JSONStyledWriter::writeWithIndent(const String &value) {
     writeIndent();
-    document_ += value;
+    document_ += value.c_str();
 }
 
 
@@ -418,18 +418,18 @@ void JSONStyledWriter::unindent() {
 void JSONStyledWriter::writeCommentBeforeValue(const JSONValue &root) {
     if(!root.hasComment(commentBefore))
         return;
-    document_ += normalizeEOL(root.getComment(commentBefore));
+    document_ += normalizeEOL(root.getComment(commentBefore).c_str());
     document_ += "\n";
 }
 
 
 void JSONStyledWriter::writeCommentAfterValueOnSameLine(const JSONValue &root) {
     if(root.hasComment(commentAfterOnSameLine))
-        document_ += " " + normalizeEOL(root.getComment(commentAfterOnSameLine));
+        document_ += " " + normalizeEOL(root.getComment(commentAfterOnSameLine).c_str());
 
     if(root.hasComment(commentAfter)) {
         document_ += "\n";
-        document_ += normalizeEOL(root.getComment(commentAfter));
+        document_ += normalizeEOL(root.getComment(commentAfter).c_str());
         document_ += "\n";
     }
 }
@@ -464,10 +464,10 @@ std::string JSONStyledWriter::normalizeEOL(const std::string &text) {
 // Class JSONStyledStreamWriter
 // //////////////////////////////////////////////////////////////////
 
-JSONStyledStreamWriter::JSONStyledStreamWriter(std::string indentation)
+JSONStyledStreamWriter::JSONStyledStreamWriter(String indentation)
     : document_(NULL)
     , rightMargin_(74)
-    , indentation_(indentation) {
+    , indentation_(indentation.c_str()) {
 }
 
 
@@ -498,7 +498,7 @@ void JSONStyledStreamWriter::writeValue(const JSONValue &value) {
             pushValue(valueToString(value.asDouble()));
             break;
         case stringValue:
-            pushValue(valueToQuotedString(value.asCString()));
+            pushValue(valueToQuotedString(value.c_str()));
             break;
         case booleanValue:
             pushValue(valueToString(value.asBool()));
@@ -552,7 +552,7 @@ void JSONStyledStreamWriter::writeArrayValue(const JSONValue &value) {
                 const JSONValue &childValue = value[index];
                 writeCommentBeforeValue(childValue);
                 if(hasChildValue)
-                    writeWithIndent(childValues_[index]);
+                    writeWithIndent(childValues_[index].c_str());
                 else {
                     writeIndent();
                     writeValue(childValue);
@@ -606,11 +606,11 @@ bool JSONStyledStreamWriter::isMultineArray(const JSONValue &value) {
 }
 
 
-void JSONStyledStreamWriter::pushValue(const std::string &value) {
+void JSONStyledStreamWriter::pushValue(const String &value) {
     if(addChildValues_)
-        childValues_.push_back(value);
+        childValues_.push_back(value.c_str());
     else
-        *document_ << value;
+        *document_ << value.c_str();
 }
 
 
@@ -631,9 +631,9 @@ void JSONStyledStreamWriter::writeIndent() {
 }
 
 
-void JSONStyledStreamWriter::writeWithIndent(const std::string &value) {
+void JSONStyledStreamWriter::writeWithIndent(const String &value) {
     writeIndent();
-    *document_ << value;
+    *document_ << value.c_str();
 }
 
 
@@ -651,18 +651,18 @@ void JSONStyledStreamWriter::unindent() {
 void JSONStyledStreamWriter::writeCommentBeforeValue(const JSONValue &root) {
     if(!root.hasComment(commentBefore))
         return;
-    *document_ << normalizeEOL(root.getComment(commentBefore));
+    *document_ << normalizeEOL(root.getComment(commentBefore).c_str());
     *document_ << "\n";
 }
 
 
 void JSONStyledStreamWriter::writeCommentAfterValueOnSameLine(const JSONValue &root) {
     if(root.hasComment(commentAfterOnSameLine))
-        *document_ << " " + normalizeEOL(root.getComment(commentAfterOnSameLine));
+        *document_ << " " + normalizeEOL(root.getComment(commentAfterOnSameLine).c_str());
 
     if(root.hasComment(commentAfter)) {
         *document_ << "\n";
-        *document_ << normalizeEOL(root.getComment(commentAfter));
+        *document_ << normalizeEOL(root.getComment(commentAfter).c_str());
         *document_ << "\n";
     }
 }
